# -*- coding: utf-8 -*-
from django.contrib import admin

from .models import *

class ComuneAdmin(admin.ModelAdmin):
    list_display = ('codice_istat', 'name', 'codice_catastale', 'get_provincia_name', 'citta_metropolitana')
    search_fields = ('name', 'codice_istat')
    list_filter = ('provincia',)

    def get_provincia_name(self, obj):
        return obj.provincia.name
    get_provincia_name.short_description = 'Provincia'
    get_provincia_name.admin_order_field = 'provincia__name'

class ProvinciaAdmin(admin.ModelAdmin):
    list_display = ('codice_provincia', 'name', 'codice_targa', 'get_regione_name')
    search_fields = ('codice_provincia', 'name')
    list_filter = ('regione',)

    def get_regione_name(self, obj):
        return obj.regione.name
    get_regione_name.short_description = 'Regione'
    get_regione_name.admin_order_field = 'regione__name'

class RegioneAdmin(admin.ModelAdmin):
    list_display = ('codice_regione', 'name')
    search_fields = ('codice_regione', 'name')

class CittaMetropolitanaAdmin(admin.ModelAdmin):
    list_display = ('codice_cittametropolitana', 'name')
    search_fields = ('codice_cittametropolitana', 'name')

admin.site.register(Regione, RegioneAdmin)
admin.site.register(Provincia, ProvinciaAdmin)
admin.site.register(Comune, ComuneAdmin)
admin.site.register(CittaMetropolitana)



from django.conf import settings
from dal.autocomplete import Select2QuerySetView
from .. import models

RESULTS_PER_PAGE = getattr(settings, "COMUNI_ITALIANI_AUTOCOMPLETE_RESULTS", 10)


class BaseAutocomplete(Select2QuerySetView):
    model_clazz = None
    limit_results = None
    forwarded_field = None
    paginate_by = RESULTS_PER_PAGE

    def get_queryset(self):
        qs = self.model_clazz.objects.all()

        if self.forwarded_field:
            fw_value = self.forwarded.get(self.forwarded_field, None)

            if fw_value:
                qs = qs.filter(**{self.forwarded_field: fw_value})

        if self.q:
            qs = qs.filter(name__istartswith=self.q)

        return qs


class RegioneAutocomplete(BaseAutocomplete):
    model_clazz = models.Regione


class ProvinciaAutocomplete(BaseAutocomplete):
    model_clazz = models.Provincia
    forwarded_field = 'regione'


class CittaMetropolitanaAutocomplete(BaseAutocomplete):
    model_clazz = models.CittaMetropolitana
    forwarded_field = 'regione'


class ComuneAutocomplete(BaseAutocomplete):
    model_clazz = models.Comune
    forwarded_field = 'provincia'



# -*- coding: utf-8 -*-
from django.db import models

class Regione(models.Model):
    codice_regione = models.IntegerField(primary_key=True, verbose_name="codice Istat")
    name = models.CharField(max_length=300, db_index=True, verbose_name='nome')

    def __str__(self):
        return self.name

    class Meta:
        ordering = ['name']
        verbose_name = 'regione'
        verbose_name_plural = 'regioni'


class CittaMetropolitana(models.Model):
    codice_cittametropolitana = models.IntegerField(primary_key=True, verbose_name="codice Istat")
    name = models.CharField(max_length=300, db_index=True, verbose_name="nome")

    def __str__(self):
        return self.name

    class Meta:
        ordering = ['name']
        verbose_name = 'città metropolitana'
        verbose_name_plural = 'città metropolitane'


class Provincia(models.Model):
    codice_provincia = models.IntegerField(primary_key=True, verbose_name="codice Istat")
    name = models.CharField(max_length=300, db_index=True, verbose_name="Nome")
    codice_targa = models.CharField(max_length=2, db_index=True)
    regione = models.ForeignKey(Regione, db_index=True, on_delete=models.PROTECT)

    def __str__(self):
        return '%s - %s' % (self.name, self.regione.name)

    class Meta:
        ordering = ['name']
        verbose_name = 'provincia'
        verbose_name_plural = 'province'


class Comune(models.Model):
    codice_istat = models.IntegerField(db_index=True, unique=True, verbose_name="codice Istat")
    codice_catastale = models.CharField(blank=True, null=True, max_length=50, db_index=True)
    name = models.CharField(max_length=300, db_index=True, verbose_name="nome")
    provincia = models.ForeignKey(Provincia, db_index=True, on_delete=models.PROTECT)
    citta_metropolitana = models.ForeignKey(CittaMetropolitana, null=True, blank=True, db_index=True, on_delete=models.PROTECT)
    is_capoluogo = models.BooleanField(default=False, verbose_name="capoluogo")
    altitudine = models.IntegerField(blank=True, null=True)
    superficie = models.FloatField(blank=True, null=True, verbose_name="superficie (kmq)")
    popolazione = models.IntegerField(blank=True, null=True)

    class Meta:
        ordering = ['name']
        verbose_name = 'comune'
        verbose_name_plural = 'comuni'

    def __str__(self):
        return '%s - %s' % (self.name, self.provincia.name)



# -*- coding: utf-8 -*-
import json

from django.core.exceptions import ObjectDoesNotExist
from django.http import JsonResponse
from django.shortcuts import render

from .models import *

def jsonize_comuni(comuni):
    result = list()

    for comune in comuni:
        result.append(
            {
                'codice_istat': comune.codice_istat,
                'codice_catastale': comune.codice_catastale,
                'name': comune.name,
                'codice_provincia': comune.provincia.codice_provincia,
                'targa_provincia': comune.provincia.codice_targa,
                'codice_cittametropolitana': comune.citta_metropolitana.codice_cittametropolitana if comune.citta_metropolitana is not None else None,
                'is_capoluogo': comune.is_capoluogo,
                'altitudine': comune.altitudine,
                'superficie': comune.superficie,
                'popolazione': comune.popolazione
            }
        )

    return result

def jsonize_cittametro(citta_metro):
    result = list()

    for cm in citta_metro:
        result.append(
            {
                'name': cm.name,
                'codice_cittametropolitana': cm.codice_cittametropolitana,
            }
        )

    return result

def jsonize_province(province):
    result = list()

    for provincia in province:
        result.append(
            {
                'codice_provincia': provincia.codice_provincia,
                'codice_targa': provincia.codice_targa,
                'name': provincia.name,
                'codice_regione': provincia.regione.codice_regione,
                'name_regione': provincia.regione.name,
            }
        )

    return result


def jsonize_regioni(regioni):
    result = list()

    for regione in regioni:
        result.append(
            {
                'codice_regione': regione.codice_regione,
                'name': regione.name,
            }
        )

    return result


def check_elenco_parameters(request, codice):
    if request.method == 'POST':
        if codice is not None or 'codice' not in request.POST:
            return (None, JsonResponse({
                'result_code': 401,
            }))

        try:
            return (int(request.POST['codice']), None)
        except ValueError:
            return (None, JsonResponse({
                'result_code': 401,
            }))
    else:
        return (int(codice), None)

def elenco_comuni_provincia(request, codice=None):
    (codice_provincia, error) = check_elenco_parameters(request, codice)

    if error is not None:
        return error

    try:
        provincia = Provincia.objects.get(codice_provincia=codice_provincia)
    except ObjectDoesNotExist:
        return JsonResponse({'result_code': 404})

    qs = Comune.objects.filter(provincia=codice_provincia).all()

    comuni = jsonize_comuni(qs)

    return JsonResponse({
        'result_code': 200,
        'codice_provincia': codice_provincia,
        'name': provincia.name,
        'codice_targa': provincia.codice_targa,
        'comuni': comuni
    })

def elenco_comuni_regione(request, codice=None):
    (codice_regione, error) = check_elenco_parameters(request, codice)

    if error is not None:
        return error

    try:
        regione = Regione.objects.get(codice_regione=codice_regione)
    except ObjectDoesNotExist:
        return JsonResponse({'result_code': 404})

    qs = Comune.objects.filter(provincia__regione=codice_regione)

    comuni = jsonize_comuni(qs)

    return JsonResponse({
        'result_code': 200,
        'codice_regione': codice_regione,
        'name': regione.name,
        'comuni': comuni
    })


def elenco_comuni_cittmetro(request, codice=None):
    (codice_citta_metro, error) = check_elenco_parameters(request, codice)

    if error is not None:
        return error

    try:
        cittm = CittaMetropolitana.objects.get(codice_cittametropolitana=codice_citta_metro)
    except ObjectDoesNotExist:
        return JsonResponse({'result_code': 404})

    qs = Comune.objects.filter(citta_metropolitana=codice_citta_metro)

    comuni = jsonize_comuni(qs)

    return JsonResponse({
        'result_code': 200,
        'codice_citta_metro': codice_citta_metro,
        'name': cittm.name,
        'comuni': comuni
    })

def elenco_citta_metro(request):
    qs = CittaMetropolitana.objects.all()

    citta_metro = jsonize_cittametro(qs)

    return JsonResponse({
        'result_code': 200,
        'citta_metro': citta_metro
    })


def elenco_province_regione(request, codice=None):
    (codice_regione, error) = check_elenco_parameters(request, codice)

    if error is not None:
        return error

    try:
        regione = Regione.objects.get(codice_regione=codice_regione)
    except ObjectDoesNotExist:
        return JsonResponse({'result_code': 404})

    qs = Provincia.objects.filter(regione=codice_regione)

    province = jsonize_province(qs)

    return JsonResponse({
        'result_code': 200,
        'codice_regione': codice_regione,
        'name': regione.name,
        'province': province
    })

def elenco_province(request):
    qs = Provincia.objects.all()
    province = jsonize_province(qs)

    return JsonResponse({
        'result_code': 200,
        'province': province
    })

def elenco_regioni(request):
    qs = Regione.objects.all()
    regioni = jsonize_regioni(qs)

    return JsonResponse({
        'result_code': 200,
        'regioni': regioni
    })

def check_ricerca_params(request):
    take = 20
    skip = 0

    if request.method != 'POST' or 'nome' not in request.POST:
        return (take, skip, JsonResponse({
            'result_code': 401,
        }))

    try:
        if 'take' in request.POST:
            take = int(request.POST['take'])

        if 'skip' in request.POST:
            skip = int(request.POST['skip'])

        if take <= 0 or skip < 0:
            raise ValueError()
    except ValueError:
        return (take, skip, JsonResponse({
            'result_code': 401,
        }))

    return (take, skip, None)

def ricerca_comune(request):
    (take, skip, error) = check_ricerca_params(request)

    if error is not None:
        return error

    qs = Comune.objects.filter(name__icontains=request.POST['nome'])[skip:skip+take]

    comuni = jsonize_comuni(qs)

    return JsonResponse({
        'result_code': 200,
        'comuni': comuni,
        'take': take,
        'skip': skip
    })

def ricerca_provincia(request):
    (take, skip, error) = check_ricerca_params(request)

    if error is not None:
        return error

    qs = Provincia.objects.filter(name__icontains=request.POST['nome'])[skip:skip+take]

    province = jsonize_province(qs)

    return JsonResponse({
        'result_code': 200,
        'province': province,
        'take': take,
        'skip': skip
    })

def ricerca_regione(request):
    (take, skip, error) = check_ricerca_params(request)

    if error is not None:
        return error

    qs = Regione.objects.filter(name__icontains=request.POST['nome'])[skip:skip+take]

    regioni = jsonize_regioni(qs)

    return JsonResponse({
        'result_code': 200,
        'regioni': regioni,
        'take': take,
        'skip': skip
    })


# -*- coding: utf-8 -*-

from django.apps import AppConfig


class ComuniItalianiAutocompleteConfig(AppConfig):
    name = 'comuni_italiani.autocomplete'
    verbose_name = "Comuni Italiani Autocomplete"



from django.conf.urls import url

from . import views

app_name = 'comuni_italiani'

urlpatterns = [
    url(r'^elenco/comuni/provincia/(?P<codice>[0-9]+)/$',
        views.elenco_comuni_provincia, name="elenco_comuni_provincia"),
    url(r'^elenco/comuni/provincia/$',
        views.elenco_comuni_provincia, name="elenco_comuni_provincia_post"),

    url(r'^elenco/comuni/regione/(?P<codice>[0-9]+)/$',
        views.elenco_comuni_regione, name="elenco_comuni_regione"),
    url(r'^elenco/comuni/regione/$',
        views.elenco_comuni_regione, name="elenco_comuni_regione_post"),

    url(r'^elenco/comuni/citta_metro/(?P<codice>[0-9]+)/$',
        views.elenco_comuni_cittmetro, name="elenco_comuni_cittmetro"),
    url(r'^elenco/comuni/citta_metro/$',
        views.elenco_comuni_cittmetro, name="elenco_comuni_cittmetro_post"),

    url(r'^elenco/province/regione/(?P<codice>[0-9]+)/$',
        views.elenco_province_regione, name="elenco_province_regione"),
    url(r'^elenco/province/regione/$',
        views.elenco_province_regione, name="elenco_province_regione_post"),

    url(r'^elenco/province/$', views.elenco_province, name="elenco_province"),
    url(r'^elenco/regioni/$', views.elenco_regioni, name="elenco_regioni"),
    url(r'^elenco/citta_metro/$', views.elenco_citta_metro, name="elenco_citta_metro"),

    url(r'^ricerca/comune/$', views.ricerca_comune, name="ricerca_comune"),
    url(r'^ricerca/provincia/$', views.ricerca_provincia, name="ricerca_provincia"),
    url(r'^ricerca/regione/$', views.ricerca_regione, name="ricerca_regione"),
]



# -*- coding: utf-8 -*-
import argparse
import csv
import os

from django.core.management.base import BaseCommand, CommandError

from comuni_italiani.models import *

default_regioni_file = os.path.join(
    os.path.abspath(os.path.join(os.path.dirname(__file__), '../../fixtures')), 'ripartizioni-reg-prov-cm.csv'
)

class Command(BaseCommand):
    help = 'Importa regioni e province italiane'

    def add_arguments(self, parser):
        parser.add_argument('-csvfile', type=argparse.FileType('r', encoding='iso-8859-15'),
                            default=default_regioni_file)

    def handle(self, *args, **options):

        csvfile = options['csvfile']

        reader = csv.DictReader(csvfile, delimiter=';')

        '''
        Importazione delle regioni, province e città metropolitane
        '''

        regioni_keys = set()

        for row in reader:
            codice_regione = row['Codice regione']

            if codice_regione is None or len(codice_regione) == 0:
                continue

            codice_regione = int(codice_regione)

            if codice_regione not in regioni_keys:
                r = Regione()
                r.codice_regione = codice_regione
                r.name = row['Denominazione regione']
                regioni_keys.add(codice_regione)
                r.save()

            codice_provincia = int(row['Codice provincia'])
            codice_citta_metropolitana = None

            try:
                codice_citta_metropolitana = int(row['Codice Città Metropolitana'])
            except ValueError:
                pass

            if codice_citta_metropolitana is not None:
                c = CittaMetropolitana()
                c.codice_cittametropolitana = codice_citta_metropolitana
                name = row['Denominazione                  Città metropolitana']
                c.name = name
                c.save()
            else:
                name = row['Denominazione provincia']

            p = Provincia()
            p.name = name
            p.codice_provincia = codice_provincia
            p.codice_targa = row['Sigla automobilistica']
            p.regione_id = codice_regione
            p.save()

        self.stdout.write("Importazione completata")



from django.urls import path
from . import views


urlpatterns = [
    path(
        'regione/',
        views.RegioneAutocomplete.as_view(),
        name='regione-autocomplete',
    ),
    path(
        'provincia/',
        views.ProvinciaAutocomplete.as_view(),
        name='provincia-autocomplete',
    ),
    path(
        'cittametropolitana/',
        views.CittaMetropolitanaAutocomplete.as_view(),
        name='cittametropolitana-autocomplete',
    ),
    path(
        'comune/',
        views.ComuneAutocomplete.as_view(),
        name='comune-autocomplete',
    ),
]



# -*- coding: utf-8 -*-
import argparse
import csv
import locale
import os
import sys

from django.core.management.base import BaseCommand, CommandError
from django.db.models import Count

from comuni_italiani.models import *

default_comuni_file = os.path.join(
    os.path.abspath(os.path.join(os.path.dirname(__file__), '../../fixtures')), 'elenco-comuni-italiani.csv'
)


locale.setlocale( locale.LC_ALL, 'it_IT.UTF-8' )

class NotRunningInTTYException(Exception):
    pass

class Command(BaseCommand):
    help = 'Importa i comuni italiani'

    def add_arguments(self, parser):
        parser.add_argument('-csvfile', type=argparse.FileType('r', encoding='iso-8859-15'),
                            default=default_comuni_file)

    def execute(self, *args, **options):
        self.stdin = options.get('stdin', sys.stdin)  # Used for testing
        return super(Command, self).execute(*args, **options)

    def handle(self, *args, **options):

        if hasattr(self.stdin, 'isatty') and not self.stdin.isatty():
            raise NotRunningInTTYException("Not running in a TTY")

        csvfile = options['csvfile']

        reader = csv.DictReader(csvfile, delimiter=';')

        counter_totale = 0
        counter_aggiunti = 0
        counter_modificati = 0
        counter_ignorati = 0

        comuni_rilevati = set()

        for row in reader:
            codice_istat = row['Codice Comune formato numerico']

            if codice_istat is None or len(codice_istat) == 0:
                continue

            counter_totale += 1

            if counter_totale % 20 == 0:
                self.stdout.write("Righe analizzate %d" % counter_totale)

            codice_istat = int(codice_istat)

            comuni_rilevati.add(codice_istat)

            name = row['Denominazione in italiano']
            provincia_id = int(row['Codice Provincia (1)'])
            codice_catastale = row['Codice Catastale del comune']
            is_capoluogo = row['Flag Comune capoluogo di provincia'] == '1'
            # Nei dati del 2016 altitudine e superficie non sono stati inseriti
            # altitudine = locale.atoi(row['Altitudine del centro (metri)'])
            # superficie = locale.atof(row['Superficie territoriale (kmq) al 09/10/2011'])
            popolazione = locale.atoi(row['Popolazione legale 2011 (09/10/2011)'])
            citta_metropolitana_id = None
            try:
                citta_metropolitana_id = int(row['Codice Città Metropolitana'])
            except ValueError:
                pass

            try:
                r = Comune.objects.get(codice_istat=codice_istat)
                # Nei dati del 2016 altitudine e superficie non sono stati inseriti
                #    r.is_capoluogo == is_capoluogo and r.altitudine == altitudine and r.superficie == superficie and \
                if r.codice_istat == codice_istat and r.name == name and r.provincia_id == provincia_id and \
                    r.codice_catastale == codice_catastale and r.citta_metropolitana_id == citta_metropolitana_id and \
                    r.is_capoluogo == is_capoluogo and \
                    r.popolazione == popolazione:
                    continue
                else:
                    ignore_me = False
                    if r.codice_istat is not None and r.name != name:
                        self.stdout.write("Rilevato cambio nome per un codice istat, assicurati che non sia una rinumerazione\n")
                        self.stdout.write("DB: %s %s\n" % (r.codice_istat, r.name))
                        self.stdout.write("CSV: %s %s\n" % (codice_istat, name))
                        valid_choice = False
                        while not valid_choice:
                            choice = input("Vuoi aggiornare questo record? [y/n] ")
                            if choice in ["y", "n"]:
                                valid_choice = True
                                if choice == "n":
                                    counter_ignorati += 1

                    if ignore_me:
                        continue

                    counter_modificati += 1
            except Comune.DoesNotExist:
                r = Comune()
                counter_aggiunti += 1

            r.codice_istat = codice_istat
            r.name = name
            r.provincia_id = provincia_id
            r.codice_catastale = codice_catastale
            r.citta_metropolitana_id = citta_metropolitana_id
            r.is_capoluogo = is_capoluogo
            # Nei dati del 2016 altitudine e superficie non sono stati inseriti
            # r.altitudine = altitudine
            # r.superficie = superficie
            r.popolazione = popolazione

            r.save()

        self.stdout.write("Totale righe analizzate: %d" % counter_totale)
        self.stdout.write("Totale comuni aggiunti: %d" % counter_aggiunti)
        self.stdout.write("Totale comuni modificati: %d" % counter_modificati)
        self.stdout.write("Totale comuni ignorati: %d" % counter_ignorati)

        '''
        Controlla i comuni con lo stesso nome per evitare che nel db sia presente lo stesso comune ma con codici
        istat diversi. In futuro il comando per analizzare il file dei cambiamenti istat dovrebbe gestire queste
        situazioni da se.
        '''
        self.stdout.write("Controllo comuni con lo stesso nome\n")
        qs = Comune.objects.values('name').annotate(count=Count('id')).filter(count__gt=1).order_by('name')
        for item in qs:
            for item2 in Comune.objects.filter(name=item['name']):
                print("%s - %s - %s" % (item2.codice_istat, item2.name, item2.provincia.name))
        self.stdout.write("Numero totale comuni con lo stesso nome: %d\n" % len(qs))

        '''
        Controlla i comuni eventualmente rimossi ma presenti nel database. Prima veniva usata una query diretta
        con exclude, ma putroppo ha iniziato a non funzionare con sqlite.
        '''
        self.stdout.write("Controllo comuni rimossi\n")
        comuni_rilevati_db = set()

        for comune in Comune.objects.all():
            comuni_rilevati_db.add(comune.codice_istat)

        comuni_eliminati_ids = comuni_rilevati_db - comuni_rilevati
        comuni_eliminati = 0

        for comune in Comune.objects.filter(codice_istat__in=comuni_eliminati_ids).order_by('codice_istat'):
            print("%s - %s - %s" % (comune.codice_istat, comune.name, comune.provincia.name))
            comuni_eliminati += 1

        self.stdout.write("Numero totale comuni presenti nel db ma rimossi da istat: %d\n" % comuni_eliminati)

        self.stdout.write("Importazione completata")



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CittaMetropolitana',
            fields=[
                ('codice_cittametropolitana', models.IntegerField(primary_key=True, serialize=False, verbose_name='codice Istat')),
                ('name', models.CharField(db_index=True, verbose_name='nome', max_length=300)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name_plural': 'città metropolitane',
                'verbose_name': 'città metropolitana',
            },
        ),
        migrations.CreateModel(
            name='Comune',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False, auto_created=True, verbose_name='ID')),
                ('codice_istat', models.IntegerField(db_index=True, verbose_name='codice Istat', unique=True)),
                ('codice_catastale', models.CharField(blank=True, db_index=True, null=True, max_length=50)),
                ('name', models.CharField(db_index=True, verbose_name='nome', max_length=300)),
                ('is_capoluogo', models.BooleanField(default=False, verbose_name='capoluogo')),
                ('altitudine', models.IntegerField(null=True, blank=True)),
                ('superficie', models.FloatField(null=True, verbose_name='superficie (kmq)', blank=True)),
                ('popolazione', models.IntegerField(null=True, blank=True)),
                ('citta_metropolitana', models.ForeignKey(to='comuni_italiani.CittaMetropolitana', on_delete=models.PROTECT, blank=True, null=True)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name_plural': 'comuni',
                'verbose_name': 'comune',
            },
        ),
        migrations.CreateModel(
            name='Provincia',
            fields=[
                ('codice_provincia', models.IntegerField(primary_key=True, serialize=False, verbose_name='codice Istat')),
                ('name', models.CharField(db_index=True, verbose_name='Nome', max_length=300)),
                ('codice_targa', models.CharField(db_index=True, max_length=2)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name_plural': 'province',
                'verbose_name': 'provincia',
            },
        ),
        migrations.CreateModel(
            name='Regione',
            fields=[
                ('codice_regione', models.IntegerField(primary_key=True, serialize=False, verbose_name='codice Istat')),
                ('name', models.CharField(db_index=True, verbose_name='nome', max_length=300)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name_plural': 'regioni',
                'verbose_name': 'regione',
            },
        ),
        migrations.AddField(
            model_name='provincia',
            name='regione',
            field=models.ForeignKey(to='comuni_italiani.Regione', on_delete=models.PROTECT),
        ),
        migrations.AddField(
            model_name='comune',
            name='provincia',
            field=models.ForeignKey(to='comuni_italiani.Provincia', on_delete=models.PROTECT),
        ),
    ]



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages


def readme():
    with open('README.txt') as f:
        return f.read()


version = '1.4.1'


setup(
    name='django-comuni-italiani',
    packages=find_packages(),
    # package_data={'': ['']},
    include_package_data=True,
    version=version,
    install_requires=[
        'Django>=1.7',
    ],
    description='A simple django (>= 1.7) app for Italian cities and regions',
    long_description=readme(),
    author='Andrea Briganti',
    author_email='kbytesys@gmail.com',
    url='https://github.com/kbytesys/django_comuni_italiani',
    download_url='https://github.com/kbytesys/django_comuni_italiani/tarball/v1.3.0',
    keywords=['django', 'comuni', 'regioni', 'province'],
    license='GNU LGPL v2',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU Lesser General Public License v2 (LGPLv2)',
        'Natural Language :: Italian',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Framework :: Django',
        'Framework :: Django :: 1.7',
        'Framework :: Django :: 1.8',
        'Framework :: Django :: 1.9',
        'Framework :: Django :: 1.10',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        'Framework :: Django :: 2.1',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
)

